# Модуль для выгрузки данных счётов NuBank
На основе - https://github.com/andreroggeri/pynubank/tree/main

# Генерация сертификата для авторизации
> poetry run python -m fdnubank.cli
- ввести CPF
- ввести пароль
- ввести код, присланный на email
В корневой папке будет создан файл cert.p12

